# Examples

- [Classification](classification): Classify customer requests.
- [Named Entity Extraction](extraction.md): Extract information from pizza orders.
- [Dating Profile](dating_profiles.md): Build dating profiles from descriptions using prompt templating and JSON-guided generation.
- [Chain Of Density](chain_of_density.md): Summarize documents using chain of density prompting and JSON-guided generation.
- [Playing Chess](models_playing_chess.md): Make Mistral-7B play chess against itself using regex-guided generation.
